==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebRangeSliderValueEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRangeSliderValueDescriptionMetadata } from "./WebRangeSliderValueDescriptionMetadata";
import { WebRangeSliderValueEventArgsDescription } from "./WebRangeSliderValueEventArgsDescription";
/**
 * @hidden
 */
var WebRangeSliderValueEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebRangeSliderValueEventArgsDescriptionMetadata, _super);
    function WebRangeSliderValueEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebRangeSliderValueEventArgsDescriptionMetadata.b = function (a) {
        if (WebRangeSliderValueEventArgsDescriptionMetadata.a == null) {
            WebRangeSliderValueEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebRangeSliderValueEventArgsDescriptionMetadata.c(WebRangeSliderValueEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebRangeSliderValueEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebRangeSliderValueEventArgsDescriptionMetadata.a);
        WebRangeSliderValueDescriptionMetadata.d(a);
    };
    WebRangeSliderValueEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:RangeSliderValueEventArgs");
        a.item("Detail", "ExportedType:WebRangeSliderValue");
    };
    WebRangeSliderValueEventArgsDescriptionMetadata.d = function (a) {
        WebRangeSliderValueEventArgsDescriptionMetadata.b(a);
        a.aa("WebRangeSliderValueEventArgs", function () { return new WebRangeSliderValueEventArgsDescription(); });
        a.z("WebRangeSliderValueEventArgs", WebRangeSliderValueEventArgsDescriptionMetadata.a);
    };
    WebRangeSliderValueEventArgsDescriptionMetadata.$t = markType(WebRangeSliderValueEventArgsDescriptionMetadata, 'WebRangeSliderValueEventArgsDescriptionMetadata');
    WebRangeSliderValueEventArgsDescriptionMetadata.a = null;
    return WebRangeSliderValueEventArgsDescriptionMetadata;
}(Base));
export { WebRangeSliderValueEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebRangeSliderValueEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRangeSliderValueDescriptionMetadata } from "./WebRangeSliderValueDescriptionMetadata";
import { WebRangeSliderValueEventArgsDescription } from "./WebRangeSliderValueEventArgsDescription";
/**
 * @hidden
 */
var WebRangeSliderValueEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebRangeSliderValueEventArgsDescriptionMetadata, _super);
    function WebRangeSliderValueEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebRangeSliderValueEventArgsDescriptionMetadata.b = function (a) {
        if (WebRangeSliderValueEventArgsDescriptionMetadata.a == null) {
            WebRangeSliderValueEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebRangeSliderValueEventArgsDescriptionMetadata.c(WebRangeSliderValueEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebRangeSliderValueEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebRangeSliderValueEventArgsDescriptionMetadata.a);
        WebRangeSliderValueDescriptionMetadata.d(a);
    };
    WebRangeSliderValueEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:RangeSliderValueEventArgs");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("Detail", "ExportedType:WebRangeSliderValue");
    };
    WebRangeSliderValueEventArgsDescriptionMetadata.d = function (a) {
        WebRangeSliderValueEventArgsDescriptionMetadata.b(a);
        a.ac("WebRangeSliderValueEventArgs", function () { return new WebRangeSliderValueEventArgsDescription(); });
        a.ab("WebRangeSliderValueEventArgs", WebRangeSliderValueEventArgsDescriptionMetadata.a);
    };
    WebRangeSliderValueEventArgsDescriptionMetadata.$t = markType(WebRangeSliderValueEventArgsDescriptionMetadata, 'WebRangeSliderValueEventArgsDescriptionMetadata');
    WebRangeSliderValueEventArgsDescriptionMetadata.a = null;
    return WebRangeSliderValueEventArgsDescriptionMetadata;
}(Base));
export { WebRangeSliderValueEventArgsDescriptionMetadata };
